#!/bin/sh
# -------------------------------------------------------------------------
# (C) Copyright Marxmeier Software AG 2008-2014
#
# Eloquence JDLG Plugin Interface
#
# Function: Sign 3rd-party JAR.
# -------------------------------------------------------------------------

# Configuration
# -------------

# Edit the values below as necessary.
#
# Note:
# - If a commercial certificate is used (see below), ALIAS is ignored.
#   Otherwise, ALIAS configures the default Java KeyStore (JKS) certificate
#   alias and must follow file naming conventions. Avoid spaces and special
#   characters.
#   If separate certificates should be used for different 3rd-party JARs,
#   first invoke "create-ca-cert.sh ALIAS" to create a separate certificate
#   for ALIAS, then invoke "sign-3rdparty-jar.sh source.jar signed.jar ALIAS"
#   to sign the JAR using that certificate.

ALIAS="jdlg-plugin"

# Configure the variables below to use a commercial code signing certificate
# wrapped into a PKCS#12 container.
#
# Notes:
# - In passwords.cnf only the KEYSTORE_PASS requires to be configured.
#   Set it to the password of the PKCS#12 file containing your certificate.
# - PKCS12_CERT : fully qualified path to your PKCS#12 certificate file
# - PKCS12_ALIAS : "friendly name" of your PKCS#12 certificate file
# - PKCS12_TSA_URL : optional, ignored if not configured
#   If set, the specified URL is used to generate a trusted timestamp for
#   the JAR signature (RFC3161).

PKCS12_CERT=""
PKCS12_ALIAS=""
PKCS12_TSA_URL=""

# Commands
JAR="jar"
JARSIGNER="jarsigner"

# -----------------
# End Configuration

if [ $# -eq 2 -o $# -eq 3 ]; then
  SRC_JAR="$1"
  DST_JAR="$2"
  if [ $# -eq 3 ]; then
    ALIAS="$3"
  fi
else
  echo "usage: $0 source.jar signed.jar ALIAS"
  exit 2
fi

if [ ! -r "$SRC_JAR" ]; then
  echo "$SRC_JAR : file not found."
  exit 2
fi

THIS_DIR="`dirname $0`"
TMP_DIR="$THIS_DIR/tmp"
TMP_SRC_JAR="$TMP_DIR/`basename $SRC_JAR`"
TMP_MANIFEST="$TMP_DIR/manifest.tmp"
KEYSTORE="$THIS_DIR/keystore.bin"
PASSWORDS_CONF="$THIS_DIR/passwords.cnf"

if [ ! -f "$KEYSTORE" ]; then
  echo "Java KeyStore file not found."
  exit 2
fi

if [ ! -r "$PASSWORDS_CONF" ]; then
  echo "Password configuration file not found."
  exit 2
fi
. "$PASSWORDS_CONF"

rm -rf "$TMP_DIR"
mkdir -p "$TMP_DIR"

# Create temporary manifest to add required attributes.
cat > "$TMP_MANIFEST" <<EOF.
Permissions: all-permissions
Codebase: *
EOF.

# Copy JAR to temporary location.
cp "$SRC_JAR" "$TMP_SRC_JAR"

# Update manifest.
"$JAR" umf "$TMP_MANIFEST" "$TMP_SRC_JAR"

# Create signed JAR.

if [ -n "$PKCS12_CERT" ]; then

  # use commercial certificate

  if [ -z "$PKCS12_ALIAS" -o -z "$KEYSTORE_PASS" ]; then
    echo "PKCS12_ALIAS or KEYSTORE_PASS not configured."
    exit 2
  fi

  OPT_TSA=""
  if [ -n "$PKCS12_TSA_URL" ]; then
    OPT_TSA="-tsa $PKCS12_TSA_URL"
  fi

  "$JARSIGNER" \
    -keystore "$PKCS12_CERT" \
    -storetype PKCS12 \
    -storepass "$KEYSTORE_PASS" \
    -signedjar "$DST_JAR" \
    $OPT_TSA "$TMP_SRC_JAR" "$PKCS12_ALIAS" \
  || exit 1

else

  # use your own CA-signed certificate

  if [ -z "$KEYSTORE_PASS" -o -z "$KEY_PASS" ]; then
    echo "KEYSTORE_PASS or KEY_PASS not configured."
    exit 2
  fi

  "$JARSIGNER" \
    -keystore "$KEYSTORE" \
    -storepass "$KEYSTORE_PASS" \
    -keypass "$KEY_PASS" \
    -signedjar "$DST_JAR" \
    "$TMP_SRC_JAR" "$ALIAS" \
  || exit 1

fi

rm -rf "$TMP_DIR"

echo
echo "Signed JAR file $DST_JAR successfully created from $SRC_JAR."
echo
